# Welcome to Watergeo 


[![image](https://img.shields.io/badge/Watergeo-blue)](https://www.youtube.com/watch?v=C65iqOSCZOY)
![image](https://img.shields.io/badge/YouTube-Channel-red)
[![image](https://img.shields.io/pypi/v/watergeo.svg)](https://pypi.python.org/pypi/watergeo)
[![image](https://img.shields.io/conda/vn/conda-forge/watergeo.svg)](https://anaconda.org/conda-forge/watergeo)

![logo](https://images-platform.99static.com/7WcMmZPzGbVHYpeaib5FcOYR314=/100x100:900x900/500x500/top/smart/99designs-contests-attachments/122/122380/attachment_122380314)
## python package for water spatial analysis


-   Free software: MIT License
-   Documentation: (https://github.com/Andyzxm/watergeo)

    

## Here is a list of features that are included in this package(Work in Progress):

- interactive map for US water accessibility
- different water use layers
- split map 
- time series for water use in US

## Introduction
- Background for water security on [Youtube](https://www.youtube.com/watch?v=C65iqOSCZOY)